Welcome to rabbitChat’s documentation! — rabbitChat 1.0.0 documentation

# Welcome to rabbitChat’s documentation!

A Chat-Server/Chat-System based on AMQP protocol(RabbitMQ Message Broker)

Home Page : https://pypi.python.org/pypi/rabbitChat

## Details

Author: | Anirban Roy Das
Email: | anirban.nick@gmail.com
Copyright(C): | 2016, Anirban Roy Das <anirban.nick@gmail.com>

Check `rabbitChat/LICENSE` file for full Copyright notice.

## Documentation:

- Overview
- Features
  - Technical Specs
  - Feature Specs
- Installation
  - Prerequisites
  - Install
- Usage
  - RabbitMQ Server
  - rabbitChat Server
- API
  - Main View
  - PubSub Module
- rabbitChat
  - Details
  - Overview
  - Technical Specs
  - Features
  - Installation
  - Usage
  - Todo

# Indices and tables

- Index
- Module Index
- Search Page